@@ -1,7 +1,7 @@
 /*
-	   Copyright (C) 2004-2015 Sergey Koposov
+       Copyright (C) 2004-2023 Sergey Koposov
 
-    Email: koposov@ast.cam.ac.uk
+    Email:  skoposov AT ed DOT ac DOT uk
 
     This file is part of Q3C.
 
@@ -18,7 +18,7 @@
     You should have received a copy of the GNU General Public License
     along with Q3C; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-*/
+ */
 
 
 #include <string.h>
@@ -121,7 +121,7 @@ Datum pgq3c_sel(PG_FUNCTION_ARGS)
 	{
 		rad = 0;
 	}
-	ratio = 3.14 * rad * rad/41252. ; /* pi*r^2/whole_sky_area */
+	ratio = 3.14 * rad * rad / 41252.;  /* pi*r^2/whole_sky_area */
 
 	/* clamp at 0, 1*/
 	CLAMP_PROBABILITY(ratio);
@@ -139,7 +139,7 @@ Datum pgq3c_seljoin(PG_FUNCTION_ARGS)
 	List   *args = (List *) PG_GETARG_POINTER(2);
 	int varRelid = 0;
 	/* Because there is no varrelid in the join selectivity call
-         * I just set it to zero */
+	 * I just set it to zero */
 	Node   *left;
 	Node *other;
 	VariableStatData vardata;
@@ -165,7 +165,7 @@ Datum pgq3c_seljoin(PG_FUNCTION_ARGS)
 	{
 		rad = 0;
 	}
-	ratio = 3.14 * rad * rad/41252. ; /* pi*r^2/whole_sky_area */
+	ratio = 3.14 * rad * rad / 41252.;  /* pi*r^2/whole_sky_area */
 
 	/* clamp at 0, 1*/
 	CLAMP_PROBABILITY(ratio);
@@ -198,7 +198,7 @@ Datum pgq3c_ang2ipix(PG_FUNCTION_ARGS)
 	static q3c_coord_t ra_buf, dec_buf;
 	static q3c_ipix_t ipix_buf;
 
-	if (invocation==0)
+	if (invocation == 0)
 	{
 
 	}
@@ -218,7 +218,7 @@ Datum pgq3c_ang2ipix(PG_FUNCTION_ARGS)
 	ra_buf = ra;
 	dec_buf = dec;
 	ipix_buf = ipix;
-	invocation=1;
+	invocation = 1;
 
 	PG_RETURN_INT64(ipix);
 }
@@ -236,7 +236,7 @@ Datum pgq3c_ang2ipix_real(PG_FUNCTION_ARGS)
 	static q3c_coord_t ra_buf, dec_buf;
 	static q3c_ipix_t ipix_buf;
 
-	if (invocation==0)
+	if (invocation == 0)
 	{
 
 	}
@@ -256,7 +256,7 @@ Datum pgq3c_ang2ipix_real(PG_FUNCTION_ARGS)
 	ra_buf = ra;
 	dec_buf = dec;
 	ipix_buf = ipix;
-	invocation=1;
+	invocation = 1;
 
 	PG_RETURN_INT64(ipix);
 }
@@ -269,25 +269,29 @@ Datum pgq3c_ipix2ang(PG_FUNCTION_ARGS)
 	q3c_coord_t ra, dec;
 
 	Datum       *data;
-	int16       typlen;
-	bool        typbyval;
-	char        typalign;
+	int16 typlen;
+	bool typbyval;
+	char typalign;
 	ArrayType  *result;
 	ipix = PG_GETARG_INT64(0);
+	if ((ipix < 0) || (ipix > Q3C_MAX_IPIX))
+	{
+		elog(ERROR, "Invalid ipix value");
 
+	}
 	q3c_ipix2ang(&hprm, ipix, &ra, &dec);
 
-	data = ( Datum *) palloc(sizeof(Datum)*2);
+	data = ( Datum *) palloc(sizeof(Datum) * 2);
 	data[0] = Float8GetDatum (ra);
 	data[1] = Float8GetDatum (dec);
 
-    /* get required info about the element type */
-    get_typlenbyvalalign(FLOAT8OID, &typlen, &typbyval, &typalign);
+	/* get required info about the element type */
+	get_typlenbyvalalign(FLOAT8OID, &typlen, &typbyval, &typalign);
 
-    /* now build the array */
-    result = construct_array(data, 2, FLOAT8OID, typlen, typbyval, typalign);
+	/* now build the array */
+	result = construct_array(data, 2, FLOAT8OID, typlen, typbyval, typalign);
 
-    PG_RETURN_ARRAYTYPE_P(result);
+	PG_RETURN_ARRAYTYPE_P(result);
 }
 
 PG_FUNCTION_INFO_V1(pgq3c_pixarea);
@@ -310,6 +314,14 @@ Datum pgq3c_pixarea(PG_FUNCTION_ARGS)
 	{
 		elog(ERROR, "Invalid depth. It should be less than 31.");
 	}
+	if (ipix < 0)
+	{
+		elog(ERROR, "Invalid ipix value");
+	}
+	if (ipix > Q3C_MAX_IPIX)
+	{
+		elog(ERROR, "Invalid ipix value");
+	}
 
 	res = q3c_pixarea(&hprm, ipix, depth);
 
@@ -349,26 +361,27 @@ Datum pgq3c_sindist_pm(PG_FUNCTION_ARGS)
 	q3c_coord_t ra1, dec1, ra2, dec2, ra1_shift, dec1_shift, cdec;
 	bool pm_enabled = true, cosdec;
 	q3c_coord_t res;
-	const int ra_arg_pos=0, dec_arg_pos=1, pmra_arg_pos=2, pmdec_arg_pos=3,
-	  cosdec_arg_pos=4, epoch_arg_pos=5, ra2_arg_pos=6, dec2_arg_pos=7,
-	  epoch2_arg_pos=8;
+	const int ra_arg_pos = 0, dec_arg_pos = 1, pmra_arg_pos = 2, pmdec_arg_pos = 3,
+	          cosdec_arg_pos = 4, epoch_arg_pos = 5, ra2_arg_pos = 6, dec2_arg_pos = 7,
+	          epoch2_arg_pos = 8;
 
 	if (PG_ARGISNULL(ra_arg_pos) || PG_ARGISNULL(dec_arg_pos) ||
-		PG_ARGISNULL(ra2_arg_pos) || PG_ARGISNULL(dec2_arg_pos))
+	    PG_ARGISNULL(ra2_arg_pos) || PG_ARGISNULL(dec2_arg_pos))
 	{
-		elog(ERROR, "The RA, DEC columns are not allowed to be null");
+		PG_RETURN_NULL();
 	}
-	
+
 	ra1 = PG_GETARG_FLOAT8(ra_arg_pos);
 	dec1 = PG_GETARG_FLOAT8(dec_arg_pos);
 
-	if (!PG_ARGISNULL(pmra_arg_pos)&&(!PG_ARGISNULL(pmdec_arg_pos))&&
-	    (!PG_ARGISNULL(epoch_arg_pos))&&(!PG_ARGISNULL(epoch2_arg_pos)))
+	if ((!PG_ARGISNULL(pmra_arg_pos)) &&
+	    (!PG_ARGISNULL(pmdec_arg_pos)) &&
+	    (!PG_ARGISNULL(epoch_arg_pos)) && (!PG_ARGISNULL(epoch2_arg_pos)))
 	{
-	    pmra1 = PG_GETARG_FLOAT8(pmra_arg_pos);
-	    pmdec1 = PG_GETARG_FLOAT8(pmdec_arg_pos);
-	    epoch1 = PG_GETARG_FLOAT8(epoch_arg_pos);
-	    epoch2 = PG_GETARG_FLOAT8(epoch2_arg_pos);
+		pmra1 = PG_GETARG_FLOAT8(pmra_arg_pos);
+		pmdec1 = PG_GETARG_FLOAT8(pmdec_arg_pos);
+		epoch1 = PG_GETARG_FLOAT8(epoch_arg_pos);
+		epoch2 = PG_GETARG_FLOAT8(epoch2_arg_pos);
 	}
 	else
 	{
@@ -378,21 +391,21 @@ Datum pgq3c_sindist_pm(PG_FUNCTION_ARGS)
 		epoch1 = 0;
 		epoch2 = 0;
 	}
-	cosdec = PG_GETARG_INT32(cosdec_arg_pos)!=0;
+	cosdec = PG_GETARG_INT32(cosdec_arg_pos) != 0;
 	ra2 = PG_GETARG_FLOAT8(ra2_arg_pos);
 	dec2 = PG_GETARG_FLOAT8(dec2_arg_pos);
 
 
-    if (pm_enabled)
+	if (pm_enabled)
 	{
-	  if (cosdec)
-	    {
-	      cdec = cos(dec1*Q3C_DEGRA);
-	    }
-	  else
-	    {
-	      cdec = 1;
-	    }
+		if (cosdec)
+		{
+			cdec = cos(dec1 * Q3C_DEGRA);
+		}
+		else
+		{
+			cdec = 1;
+		}
 		ra1_shift = ra1 + pmra1 * (epoch2 - epoch1) / cdec / 3600000;
 		dec1_shift = dec1 + pmdec1 * (epoch2 - epoch1) / 3600000;
 	}
@@ -410,30 +423,30 @@ PG_FUNCTION_INFO_V1(pgq3c_dist_pm);
 Datum pgq3c_dist_pm(PG_FUNCTION_ARGS)
 {
 	q3c_coord_t pmra1, pmdec1, epoch1, epoch2;
-	q3c_coord_t ra1, dec1, ra2, dec2, ra1_shift, dec1_shift, cdec=1;
+	q3c_coord_t ra1, dec1, ra2, dec2, ra1_shift, dec1_shift, cdec = 1;
 	bool pm_enabled = true, cosdec;
 	q3c_coord_t res;
 
-	const int ra_arg_pos=0, dec_arg_pos=1, pmra_arg_pos=2, pmdec_arg_pos=3,
-	  cosdec_arg_pos=4, epoch_arg_pos=5, ra2_arg_pos=6, dec2_arg_pos=7,
-	  epoch2_arg_pos=8;
+	const int ra_arg_pos = 0, dec_arg_pos = 1, pmra_arg_pos = 2, pmdec_arg_pos = 3,
+	          cosdec_arg_pos = 4, epoch_arg_pos = 5, ra2_arg_pos = 6, dec2_arg_pos = 7,
+	          epoch2_arg_pos = 8;
 
 	if (PG_ARGISNULL(ra_arg_pos) || PG_ARGISNULL(dec_arg_pos) ||
-		PG_ARGISNULL(ra2_arg_pos) || PG_ARGISNULL(dec2_arg_pos))
+	    PG_ARGISNULL(ra2_arg_pos) || PG_ARGISNULL(dec2_arg_pos))
 	{
-		elog(ERROR, "The RA, DEC columns are not allowed to be null");
+		PG_RETURN_NULL();
 	}
-	
+
 	ra1 = PG_GETARG_FLOAT8(ra_arg_pos);
 	dec1 = PG_GETARG_FLOAT8(dec_arg_pos);
 
-	if (!PG_ARGISNULL(pmra_arg_pos)&&(!PG_ARGISNULL(pmdec_arg_pos))&&
-	    (!PG_ARGISNULL(epoch_arg_pos))&&(!PG_ARGISNULL(epoch2_arg_pos)))
+	if ((!PG_ARGISNULL(pmra_arg_pos)) && (!PG_ARGISNULL(pmdec_arg_pos)) &&
+	    (!PG_ARGISNULL(epoch_arg_pos)) && (!PG_ARGISNULL(epoch2_arg_pos)))
 	{
-	    pmra1 = PG_GETARG_FLOAT8(pmra_arg_pos);
-	    pmdec1 = PG_GETARG_FLOAT8(pmdec_arg_pos);
-	    epoch1 = PG_GETARG_FLOAT8(epoch_arg_pos);
-	    epoch2 = PG_GETARG_FLOAT8(epoch2_arg_pos);
+		pmra1 = PG_GETARG_FLOAT8(pmra_arg_pos);
+		pmdec1 = PG_GETARG_FLOAT8(pmdec_arg_pos);
+		epoch1 = PG_GETARG_FLOAT8(epoch_arg_pos);
+		epoch2 = PG_GETARG_FLOAT8(epoch2_arg_pos);
 	}
 	else
 	{
@@ -443,21 +456,21 @@ Datum pgq3c_dist_pm(PG_FUNCTION_ARGS)
 		epoch1 = 0;
 		epoch2 = 0;
 	}
-	cosdec = PG_GETARG_INT32(cosdec_arg_pos)!=0;
+	cosdec = PG_GETARG_INT32(cosdec_arg_pos) != 0;
 	ra2 = PG_GETARG_FLOAT8(ra2_arg_pos);
 	dec2 = PG_GETARG_FLOAT8(dec2_arg_pos);
 
 
-    if (pm_enabled)
+	if (pm_enabled)
 	{
-	  if (cosdec)
-	    {
-	      cdec = cos(dec1*Q3C_DEGRA);
-	    }
-	  else
-	    {
-	      cdec = 1;
-	    }
+		if (cosdec)
+		{
+			cdec = cos(dec1 * Q3C_DEGRA);
+		}
+		else
+		{
+			cdec = 1;
+		}
 		ra1_shift = ra1 + pmra1 * (epoch2 - epoch1) / cdec / 3600000;
 		dec1_shift = dec1 + pmdec1 * (epoch2 - epoch1) / 3600000;
 	}
@@ -495,10 +508,10 @@ Datum pgq3c_nearby_it(PG_FUNCTION_ARGS)
 	if (invocation == 0)
 	/* If this is the first invocation of the function */
 	{
-	/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
-   	 * ipix_buf. Because if the program will be canceled or crashed
-	 * for some reason the invocation should be == 0
- 	 */
+		/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
+		 * ipix_buf. Because if the program will be canceled or crashed
+		 * for some reason the invocation should be == 0
+		 */
 	}
 	else
 	{
@@ -509,7 +522,7 @@ Datum pgq3c_nearby_it(PG_FUNCTION_ARGS)
 	}
 
 	ra_cen = UNWRAP_RA(ra_cen);
-	if (q3c_fabs(dec_cen)>90) {dec_cen = q3c_fmod(dec_cen,90);}
+	if (q3c_fabs(dec_cen) > 90) {dec_cen = q3c_fmod(dec_cen,90);}
 	circle.ra = ra_cen;
 	circle.dec = dec_cen;
 	circle.rad = radius;
@@ -524,7 +537,7 @@ Datum pgq3c_nearby_it(PG_FUNCTION_ARGS)
 	dec_cen_buf = dec_cen;
 	radius_buf = radius;
 
-	invocation=1;
+	invocation = 1;
 	PG_RETURN_INT64(ipix_array_buf[iteration]);
 }
 
@@ -542,26 +555,26 @@ Datum pgq3c_nearby_pm_it(PG_FUNCTION_ARGS)
 	q3c_circle_region circle;
 	q3c_coord_t new_radius;
 	q3c_coord_t ra_cen, dec_cen, pmra, pmdec;
-	q3c_coord_t max_epoch_delta=0, radius=0;
+	q3c_coord_t max_epoch_delta = 0, radius = 0;
 	bool pm_enabled = true, cosdec;
 	int iteration;
-	const int ra_arg_pos=0, dec_arg_pos=1, pmra_arg_pos=2, pmdec_arg_pos=3,
-	  cosdec_arg_pos=4, maxepochdelta_arg_pos=5, radius_arg_pos=6, iteration_arg_pos=7;
+	const int ra_arg_pos = 0, dec_arg_pos = 1, pmra_arg_pos = 2, pmdec_arg_pos = 3,
+	          cosdec_arg_pos = 4, maxepochdelta_arg_pos = 5, radius_arg_pos = 6, iteration_arg_pos = 7;
 
 	if (PG_ARGISNULL(ra_arg_pos) || PG_ARGISNULL(dec_arg_pos) || PG_ARGISNULL(radius_arg_pos))
-	  {
-	    elog(ERROR, "Right Ascensions and raddii must be not null");
-	  }
+	{
+		elog(ERROR, "Right Ascensions and raddii must be not null");
+	}
 
 	ra_cen = PG_GETARG_FLOAT8(ra_arg_pos); // ra_cen
 	dec_cen = PG_GETARG_FLOAT8(dec_arg_pos); // dec_cen
 
-	if (!PG_ARGISNULL(pmra_arg_pos)&&(!PG_ARGISNULL(pmdec_arg_pos))&&
+	if ((!PG_ARGISNULL(pmra_arg_pos)) && (!PG_ARGISNULL(pmdec_arg_pos)) &&
 	    (!PG_ARGISNULL(maxepochdelta_arg_pos)))
 	{
-	    pmra = PG_GETARG_FLOAT8(pmra_arg_pos);
-	    pmdec = PG_GETARG_FLOAT8(pmdec_arg_pos);
-	    max_epoch_delta = PG_GETARG_FLOAT8(maxepochdelta_arg_pos);
+		pmra = PG_GETARG_FLOAT8(pmra_arg_pos);
+		pmdec = PG_GETARG_FLOAT8(pmdec_arg_pos);
+		max_epoch_delta = PG_GETARG_FLOAT8(maxepochdelta_arg_pos);
 	}
 	else
 	{
@@ -571,7 +584,7 @@ Datum pgq3c_nearby_pm_it(PG_FUNCTION_ARGS)
 		max_epoch_delta = 0;
 	}
 
-	cosdec = PG_GETARG_INT32(cosdec_arg_pos)!=0;
+	cosdec = PG_GETARG_INT32(cosdec_arg_pos) != 0;
 	radius = PG_GETARG_FLOAT8(radius_arg_pos); // error radius
 
 	iteration = PG_GETARG_INT32(iteration_arg_pos); // iteration
@@ -581,46 +594,46 @@ Datum pgq3c_nearby_pm_it(PG_FUNCTION_ARGS)
 		elog(ERROR, "The values of ra,dec are infinites or NaNs");
 	}
 	if ( (!isfinite(pmra)) || (!isfinite(pmdec)) ||
-		(!isfinite(max_epoch_delta)) )
+	     (!isfinite(max_epoch_delta)) )
 	{
-		pmra =  0;
+		pmra = 0;
 		pmdec = 0;
 		max_epoch_delta = 0;
 	}
-	if (max_epoch_delta<0)
+	if (max_epoch_delta < 0)
 	{
 		elog(ERROR, "The maximum epoch difference must be >=0 ");
 	}
 	if (invocation == 0)
 	/* If this is the first invocation of the function */
 	{
-	/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
-   	 * ipix_buf. Because if the program will be canceled or crashed
-	 * for some reason the invocation should be == 0
- 	 */
+		/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
+		 * ipix_buf. Because if the program will be canceled or crashed
+		 * for some reason the invocation should be == 0
+		 */
 	}
 	else
 	{
-	  if ((ra_cen == ra_cen_buf) && (dec_cen == dec_cen_buf) &&
-	  	(radius == radius_buf) && (pmra == pmra_buf) &&
-		(pmdec == pmdec_buf) && (max_epoch_delta == max_epoch_delta_buf))
+		if ((ra_cen == ra_cen_buf) && (dec_cen == dec_cen_buf) &&
+		    (radius == radius_buf) && (pmra == pmra_buf) &&
+		    (pmdec == pmdec_buf) && (max_epoch_delta == max_epoch_delta_buf))
 		{
 			PG_RETURN_INT64(ipix_array_buf[iteration]);
 		}
 	}
 
 	if (pm_enabled)
-	  {
-	    q3c_coord_t pmra1;
-	    if (cosdec) { pmra1 = pmra ; } else { pmra1 = pmra * cos(Q3C_DEGRA*dec_cen);}
-	    new_radius = q3c_sqrt(pmra1 * pmra1 + pmdec * pmdec)/ 3600000 * max_epoch_delta + radius;
-	  }
+	{
+		q3c_coord_t pmra1;
+		if (cosdec) { pmra1 = pmra; } else { pmra1 = pmra * cos(Q3C_DEGRA * dec_cen);}
+		new_radius = q3c_sqrt(pmra1 * pmra1 + pmdec * pmdec) / 3600000 * max_epoch_delta + radius;
+	}
 	else
-	  {
-	    new_radius = radius;
-	  }
+	{
+		new_radius = radius;
+	}
 	ra_cen = UNWRAP_RA(ra_cen);
-	if (q3c_fabs(dec_cen)>90) {dec_cen = q3c_fmod(dec_cen,90);}
+	if (q3c_fabs(dec_cen) > 90) {dec_cen = q3c_fmod(dec_cen,90);}
 	circle.ra = ra_cen;
 	circle.dec = dec_cen;
 	circle.rad = new_radius;
@@ -638,7 +651,7 @@ Datum pgq3c_nearby_pm_it(PG_FUNCTION_ARGS)
 	max_epoch_delta_buf = max_epoch_delta;
 	pmra_buf = pmra;
 	pmdec_buf = pmdec;
-	invocation=1;
+	invocation = 1;
 	PG_RETURN_INT64(ipix_array_buf[iteration]);
 }
 
@@ -670,23 +683,23 @@ Datum pgq3c_ellipse_nearby_it(PG_FUNCTION_ARGS)
 	if (invocation == 0)
 	/* If this is the first invocation of the function */
 	{
-	/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
-	 * ipix_buf. Because if the program will be canceled or crashed
-	 * for some reason the invocation should be == 0
-	 */
+		/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
+		 * ipix_buf. Because if the program will be canceled or crashed
+		 * for some reason the invocation should be == 0
+		 */
 	}
 	else
 	{
 		if ((ra_cen == ra_cen_buf) && (dec_cen == dec_cen_buf) &&
-			(radius == radius_buf) && (PA == PA_buf) &&
-			(axis_ratio == axis_ratio_buf))
+		    (radius == radius_buf) && (PA == PA_buf) &&
+		    (axis_ratio == axis_ratio_buf))
 		{
 			PG_RETURN_INT64(ipix_array_buf[iteration]);
 		}
 	}
 
 	ra_cen = UNWRAP_RA(ra_cen);
-	if (q3c_fabs(dec_cen)>90) {dec_cen = q3c_fmod(dec_cen,90);}
+	if (q3c_fabs(dec_cen) > 90) {dec_cen = q3c_fmod(dec_cen,90);}
 
 	ellipse.ra = ra_cen;
 	ellipse.dec = dec_cen;
@@ -707,7 +720,7 @@ Datum pgq3c_ellipse_nearby_it(PG_FUNCTION_ARGS)
 	axis_ratio_buf = axis_ratio;
 	PA_buf = PA;
 
-	invocation=1;
+	invocation = 1;
 	PG_RETURN_INT64(ipix_array_buf[iteration]);
 }
 
@@ -739,7 +752,7 @@ Datum pgq3c_radial_query_it(PG_FUNCTION_ARGS)
 	static int invocation;
 
 	ra_cen = UNWRAP_RA(ra_cen);
-	if (q3c_fabs(dec_cen)>90)
+	if (q3c_fabs(dec_cen) > 90)
 	{
 		elog(ERROR, "The absolute value of declination > 90!");
 	}
@@ -748,10 +761,10 @@ Datum pgq3c_radial_query_it(PG_FUNCTION_ARGS)
 	if (invocation == 0)
 	/* If this is the first invocation of the function */
 	{
-	/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
-	 * ipix_buf. Because if the program will be canceled or crashed
-	 * for some reason the invocation should be == 0
-	 */
+		/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
+		 * ipix_buf. Because if the program will be canceled or crashed
+		 * for some reason the invocation should be == 0
+		 */
 	}
 	else
 	{
@@ -811,7 +824,7 @@ Datum pgq3c_ellipse_query_it(PG_FUNCTION_ARGS)
 	static int invocation;
 
 	ra_cen = UNWRAP_RA(ra_cen);
-	if (q3c_fabs(dec_cen)>90)
+	if (q3c_fabs(dec_cen) > 90)
 	{
 		elog(ERROR, "The absolute value of declination > 90!");
 	}
@@ -820,10 +833,10 @@ Datum pgq3c_ellipse_query_it(PG_FUNCTION_ARGS)
 	if (invocation == 0)
 	/* If this is the first invocation of the function */
 	{
-	/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
-	 * ipix_buf. Because if the program will be canceled or crashed
-	 * for some reason the invocation should be == 0
-	 */
+		/* I should set invocation=1 ONLY!!! after setting ra_cen_buf, dec_cen_buf and
+		 * ipix_buf. Because if the program will be canceled or crashed
+		 * for some reason the invocation should be == 0
+		 */
 	}
 	else
 	{
@@ -841,7 +854,7 @@ Datum pgq3c_ellipse_query_it(PG_FUNCTION_ARGS)
 	}
 
 	q3c_ellipse_query(&hprm, ra_cen, dec_cen, radius, ell, PA, fulls,
-		partials);
+	                  partials);
 
 	ra_cen_buf = ra_cen;
 	dec_cen_buf = dec_cen;
@@ -859,18 +872,18 @@ Datum pgq3c_ellipse_query_it(PG_FUNCTION_ARGS)
 }
 
 static q3c_coord_t read_from_array(char **p, bits8 *bitmap, int *bitmask, bool typbyval,
-	char typalign, int16 typlen)
+                                   char typalign, int16 typlen)
 {
 	q3c_coord_t val;
 
 	/* Taken from /pgsql/src/backend/utils/adt/arrayfuncs.c
 	 * function deconstruct_array
-	*/
+	 */
 	if (bitmap && (*bitmap & *bitmask) == 0)
 	{
 		ereport(ERROR,
-		(errcode(ERRCODE_NULL_VALUE_NOT_ALLOWED),
-		errmsg("null array element not allowed in this context")));
+		        (errcode(ERRCODE_NULL_VALUE_NOT_ALLOWED),
+		         errmsg("null array element not allowed in this context")));
 	}
 	val = DatumGetFloat8(fetch_att(*p, typbyval, typlen));
 	*p = att_addlength_pointer(*p, typlen, PointerGetDatum(p));
@@ -890,7 +903,7 @@ static q3c_coord_t read_from_array(char **p, bits8 *bitmap, int *bitmask, bool t
 static int convert_pgarray2poly(ArrayType *poly_arr, q3c_coord_t *in_ra, q3c_coord_t *in_dec, int *nvert)
 {
 	int poly_nitems = ArrayGetNItems(ARR_NDIM(poly_arr), ARR_DIMS(poly_arr));
-	Oid element_type=FLOAT8OID;
+	Oid element_type = FLOAT8OID;
 	int identical = 1;
 	int16 typlen;
 	bool typbyval;
@@ -906,22 +919,25 @@ static int convert_pgarray2poly(ArrayType *poly_arr, q3c_coord_t *in_ra, q3c_coo
 	 * function deconstruct_array
 	 */
 
-	if (poly_nitems % 2 != 0)
+	if ((poly_nitems % 2) != 0)
 	{
-		 elog(ERROR, "Invalid array argument!\nThe array should contain even number of elements");
+		elog(ERROR, "Invalid array argument!\nThe array should contain even number of elements");
 	}
 	else if (poly_nitems <= 4)
 	{
 		elog(ERROR, "Invalid polygon! The polygon must have more than two vertices");
 	}
-
+	else if (poly_nitems > (2 * Q3C_MAX_N_POLY_VERTEX))
+	{
+		elog(ERROR,"Polygons with more than 100 vertices are not supported");
+	}
 	p = ARR_DATA_PTR(poly_arr);
 	poly_nitems /= 2;
 	*nvert = poly_nitems;
 	identical = 1;
 
 	bitmap = ARR_NULLBITMAP(poly_arr);
-	bitmask=1;
+	bitmask = 1;
 
 	for (i = 0; i < poly_nitems; i++)
 	{
@@ -950,12 +966,16 @@ static int convert_pgpoly2poly(POLYGON *poly, q3c_coord_t *ra, q3c_coord_t *dec,
 	{
 		elog(ERROR, "Invalid polygon! The polygon must have more than two vertices");
 	}
+	else if (npts > Q3C_MAX_N_POLY_VERTEX)
+	{
+		elog(ERROR,"Polygons with more than 100 vertices are not supported");
+	}
 
-	for(i=0;i<npts;i++)
+	for(i = 0; i < npts; i++)
 	{
 		newx = poly->p[i].x;
 		newy = poly->p[i].y;
-		if ((newx != ra[i]) || (newy !=dec[i]))	{identical=0;}
+		if ((newx != ra[i]) || (newy != dec[i])) {identical = 0;}
 		ra[i] = newx;
 		dec[i] = newy;
 	}
@@ -963,20 +983,20 @@ static int convert_pgpoly2poly(POLYGON *poly, q3c_coord_t *ra, q3c_coord_t *dec,
 }
 
 
-typedef struct q3c_poly_info_type{
+typedef struct q3c_poly_info_type {
 	/*  !!!!!!!!!! IMPORTANT !!!!!!!!!!!!!!!
-	* Here the Q3C_NPARTIALS and Q3C_NFULLS is the number of pairs !!! of ranges
-	* So we should have the array with the size twice bigger
-	*/
+	 * Here the Q3C_NPARTIALS and Q3C_NFULLS is the number of pairs !!! of ranges
+	 * So we should have the array with the size twice bigger
+	 */
 	int ready;
 	q3c_ipix_t partials[2 * Q3C_NPARTIALS]; /* array of ipixes partially covered */
 	q3c_ipix_t fulls[2 * Q3C_NFULLS]; /* array of ipixes fully covered */
 	q3c_coord_t ra[Q3C_MAX_N_POLY_VERTEX],
-		dec[Q3C_MAX_N_POLY_VERTEX], x[Q3C_MAX_N_POLY_VERTEX],y[Q3C_MAX_N_POLY_VERTEX],
-		ax[Q3C_MAX_N_POLY_VERTEX], ay[Q3C_MAX_N_POLY_VERTEX];
+	            dec[Q3C_MAX_N_POLY_VERTEX], x[Q3C_MAX_N_POLY_VERTEX],y[Q3C_MAX_N_POLY_VERTEX],
+	            ax[Q3C_MAX_N_POLY_VERTEX], ay[Q3C_MAX_N_POLY_VERTEX];
 	q3c_coord_t xpj[3][Q3C_MAX_N_POLY_VERTEX], ypj[3][Q3C_MAX_N_POLY_VERTEX],
-			axpj[3][Q3C_MAX_N_POLY_VERTEX], aypj[3][Q3C_MAX_N_POLY_VERTEX];
-		// arrays storing the ra,dec ,projected x,y
+	            axpj[3][Q3C_MAX_N_POLY_VERTEX], aypj[3][Q3C_MAX_N_POLY_VERTEX];
+	// arrays storing the ra,dec ,projected x,y
 	char faces[6];
 	char multi_flag;
 	/* IF YOU MAKE CHANGES MAKE SURE YOU CHANGE THE COPY() FUNCTION */
@@ -985,15 +1005,15 @@ typedef struct q3c_poly_info_type{
 static void copy_q3c_poly_info_type(q3c_poly_info_type *a, q3c_poly_info_type *b)
 {
 	int i,j;
-	for (i=0; i<(2* Q3C_NPARTIALS); i++)
+	for (i = 0; i < (2 * Q3C_NPARTIALS); i++)
 	{
-		b->partials[i]=a->partials[i];
+		b->partials[i] = a->partials[i];
 	}
-	for (i=0; i<(2* Q3C_NPARTIALS); i++)
+	for (i = 0; i < (2 * Q3C_NPARTIALS); i++)
 	{
-		b->fulls[i]=a->fulls[i];
+		b->fulls[i] = a->fulls[i];
 	}
-	for (i=0;i<Q3C_MAX_N_POLY_VERTEX;i++)
+	for (i = 0; i < Q3C_MAX_N_POLY_VERTEX; i++)
 	{
 		b->ra[i] = a->ra[i];
 		b->dec[i] = a->dec[i];
@@ -1001,17 +1021,17 @@ static void copy_q3c_poly_info_type(q3c_poly_info_type *a, q3c_poly_info_type *b
 		b->y[i] = a->y[i];
 		b->ax[i] = a->ax[i];
 		b->ay[i] = a->ay[i];
-		for (j=0;j<3;j++)
+		for (j = 0; j < 3; j++)
 		{
-			b->axpj[j][i]=a->axpj[j][i];
-			b->aypj[j][i]=a->aypj[j][i];
-			b->xpj[j][i]=a->xpj[j][i];
-			b->ypj[j][i]=a->ypj[j][i];
+			b->axpj[j][i] = a->axpj[j][i];
+			b->aypj[j][i] = a->aypj[j][i];
+			b->xpj[j][i] = a->xpj[j][i];
+			b->ypj[j][i] = a->ypj[j][i];
 
 		}
 
 	}
-	for (i=0;i<6;i++)
+	for (i = 0; i < 6; i++)
 	{
 		b->faces[i] = a->faces[i];
 	}
@@ -1020,17 +1040,17 @@ static void copy_q3c_poly_info_type(q3c_poly_info_type *a, q3c_poly_info_type *b
 
 
 /* Cache logic here is the following
-when the function is called for the first time with iteration =0
-I compute everything allocate memory and store computations in the static variable
-and locally allocated q3c_poly_info_table
-when the function is called for the first time and iteration  !=0
-I allocate new memory, copy stuff from static variable into locally allocated stuff
-I make no checks of the data
-If the function is called for the second time (i.e. fn_extra is not null)
-I blindly assume everything is EXACTLY the same and do not recompute anything
-as the q3c_poly_query_it() is the internal function and is ONLY supposed
-to be called with the constant polygon
-*/
+   when the function is called for the first time with iteration =0
+   I compute everything allocate memory and store computations in the static variable
+   and locally allocated q3c_poly_info_table
+   when the function is called for the first time and iteration  !=0
+   I allocate new memory, copy stuff from static variable into locally allocated stuff
+   I make no checks of the data
+   If the function is called for the second time (i.e. fn_extra is not null)
+   I blindly assume everything is EXACTLY the same and do not recompute anything
+   as the q3c_poly_query_it() is the internal function and is ONLY supposed
+   to be called with the constant polygon
+ */
 PG_FUNCTION_INFO_V1(pgq3c_poly_query_it);
 Datum pgq3c_poly_query_it(PG_FUNCTION_ARGS)
 {
@@ -1045,18 +1065,18 @@ Datum pgq3c_poly_query_it(PG_FUNCTION_ARGS)
 	q3c_poly qp;
 	static int good_cache;
 	int first_call;
-	int identical=0;
+	int identical = 0;
 	static q3c_poly_info_type lqpit;
 
-	if (fcinfo->flinfo->fn_extra==0)
+	if (fcinfo->flinfo->fn_extra == 0)
 	{
 		// allocate memory where we are going to store converted info
 		fcinfo->flinfo->fn_extra = MemoryContextAlloc(fcinfo->flinfo->fn_mcxt, sizeof(q3c_poly_info_type));
-		first_call=1;
+		first_call = 1;
 	}
 	else
 	{
-		first_call =0;
+		first_call = 0;
 	}
 
 	qpit = (q3c_poly_info_type*) (fcinfo->flinfo->fn_extra);
@@ -1096,11 +1116,11 @@ Datum pgq3c_poly_query_it(PG_FUNCTION_ARGS)
 			elog(ERROR, "The polygon is too large. Polygons having diameter >~23 degrees are unsupported");
 		}
 	}
-	if (iteration==0)
+	if (iteration == 0)
 	{
-		good_cache=0;
+		good_cache = 0;
 		copy_q3c_poly_info_type(qpit, &lqpit);
-		good_cache=1;
+		good_cache = 1;
 	}
 
 	if (full_flag)
@@ -1127,18 +1147,18 @@ Datum pgq3c_poly_query1_it(PG_FUNCTION_ARGS)
 	q3c_poly qp;
 	static int good_cache;
 	int first_call;
-	int identical=0;
+	int identical = 0;
 	static q3c_poly_info_type lqpit;
 
-	if (fcinfo->flinfo->fn_extra==0)
+	if (fcinfo->flinfo->fn_extra == 0)
 	{
 		// allocate memory where we are going to store converted info
 		fcinfo->flinfo->fn_extra = MemoryContextAlloc(fcinfo->flinfo->fn_mcxt, sizeof(q3c_poly_info_type));
-		first_call=1;
+		first_call = 1;
 	}
 	else
 	{
-		first_call =0;
+		first_call = 0;
 	}
 
 	qpit = (q3c_poly_info_type*) (fcinfo->flinfo->fn_extra);
@@ -1178,11 +1198,11 @@ Datum pgq3c_poly_query1_it(PG_FUNCTION_ARGS)
 			elog(ERROR, "The polygon is too large. Polygons having diameter >~23 degrees are unsupported");
 		}
 	}
-	if (iteration==0)
+	if (iteration == 0)
 	{
-		good_cache=0;
+		good_cache = 0;
 		copy_q3c_poly_info_type(qpit, &lqpit);
-		good_cache=1;
+		good_cache = 1;
 	}
 
 	if (full_flag)
@@ -1229,7 +1249,7 @@ Datum pgq3c_in_poly(PG_FUNCTION_ARGS)
 	int identical;
 	q3c_poly_info_type *qpit;
 
-	if (fcinfo->flinfo->fn_extra==0)
+	if (fcinfo->flinfo->fn_extra == 0)
 	{
 		// allocate memory where we are going to store converted info
 		fcinfo->flinfo->fn_extra = MemoryContextAlloc(fcinfo->flinfo->fn_mcxt, sizeof(q3c_poly_info_type));
@@ -1241,11 +1261,11 @@ Datum pgq3c_in_poly(PG_FUNCTION_ARGS)
 	identical = convert_pgarray2poly(poly_arr, qpit->ra, qpit->dec, &nvert) && qpit->ready;
 
 	result = q3c_check_sphere_point_in_poly(&hprm, nvert, qpit->ra, qpit->dec,
-											ra_cen, dec_cen, &too_large, identical,
-											qpit->xpj, qpit->ypj,
-										  qpit->axpj, qpit->aypj,
-										  qpit->faces, &(qpit->multi_flag)
-										) !=	Q3C_DISJUNCT;
+	                                        ra_cen, dec_cen, &too_large, identical,
+	                                        qpit->xpj, qpit->ypj,
+	                                        qpit->axpj, qpit->aypj,
+	                                        qpit->faces, &(qpit->multi_flag)
+	                                        ) !=    Q3C_DISJUNCT;
 	if (too_large)
 	{
 		elog(ERROR, "The polygon is too large. Polygons having diameter >~23 degrees are unsupported");
@@ -1269,7 +1289,7 @@ Datum pgq3c_in_poly1(PG_FUNCTION_ARGS)
 	int identical;
 	q3c_poly_info_type *qpit;
 
-	if (fcinfo->flinfo->fn_extra==0)
+	if (fcinfo->flinfo->fn_extra == 0)
 	{
 		// allocate memory where we are going to store converted info
 		fcinfo->flinfo->fn_extra = MemoryContextAlloc(fcinfo->flinfo->fn_mcxt, sizeof(q3c_poly_info_type));
@@ -1281,11 +1301,11 @@ Datum pgq3c_in_poly1(PG_FUNCTION_ARGS)
 	identical = convert_pgpoly2poly(poly, qpit->ra, qpit->dec, &nvert) && qpit->ready;
 
 	result = q3c_check_sphere_point_in_poly(&hprm, nvert, qpit->ra, qpit->dec,
-											ra_cen, dec_cen, &too_large, identical,
-											qpit->xpj, qpit->ypj,
-										  qpit->axpj, qpit->aypj,
-										  qpit->faces, &(qpit->multi_flag)
-										) !=	Q3C_DISJUNCT;
+	                                        ra_cen, dec_cen, &too_large, identical,
+	                                        qpit->xpj, qpit->ypj,
+	                                        qpit->axpj, qpit->aypj,
+	                                        qpit->faces, &(qpit->multi_flag)
+	                                        ) !=    Q3C_DISJUNCT;
 	qpit->ready = 1;
 	if (too_large)
 	{
